pub enum PolyscopeError {
NotInitialized,
AlreadyInitialized,
StructureExists(String),
StructureNotFound(String),
QuantityExists(String, String),
QuantityNotFound(String, String),
MaterialExists(String),
MaterialLoadError(String),
SizeMismatch {
expected: usize,
actual: usize,
},
RenderError(String),
IoError(Error),
JsonError(Error),
}Expand description
The main error type for polyscope-rs operations.
Variants
NotInitialized
Polyscope has not been initialized.
AlreadyInitialized
Polyscope has already been initialized.
StructureExists(String)
A structure with the given name already exists.
StructureNotFound(String)
A structure with the given name was not found.
QuantityExists(String, String)
A quantity with the given name already exists.
QuantityNotFound(String, String)
A quantity with the given name was not found.
MaterialExists(String)
A material with the given name already exists.
MaterialLoadError(String)
Failed to load a material image.
SizeMismatch
Data size mismatch.
RenderError(String)
Rendering error.
IoError(Error)
I/O error.
JsonError(Error)
JSON serialization error.