set_file_drop_callback

Function set_file_drop_callback 

pub fn set_file_drop_callback(
    callback: impl FnMut(&[PathBuf]) + Send + Sync + 'static,
)
Sets a callback that is invoked when files are dropped onto the polyscope window.

The callback receives a slice of file paths that were dropped.

Example

polyscope_rs::set_file_drop_callback(|paths| {
    for path in paths {
        println!("Dropped: {}", path.display());
    }
});