pub fn shutdown()Expand description
Shuts down polyscope and releases all resources.
This clears all registered structures and resets the global state.
After calling this, you can call init() again to reinitialize.
Note: This is typically not needed as resources are cleaned up when the program exits. It’s mainly useful for tests or when you need to reset the visualization state.