with_camera_view

Function with_camera_view 

pub fn with_camera_view<F, R>(name: &str, f: F) -> Option<R>
where F: FnOnce(&mut CameraView) -> R,
Executes a closure with mutable access to a registered camera view.

Returns None if the camera view does not exist.