with_point_cloud

Function with_point_cloud 

pub fn with_point_cloud<F, R>(name: &str, f: F) -> Option<R>
where F: FnOnce(&mut PointCloud) -> R,
Executes a closure with mutable access to a registered point cloud.

Returns None if the point cloud does not exist.