with_volume_grid

Function with_volume_grid 

pub fn with_volume_grid<F, R>(name: &str, f: F) -> Option<R>
where F: FnOnce(&mut VolumeGrid) -> R,
Executes a closure with mutable access to a registered volume grid.

Returns None if the volume grid does not exist.