pub struct VolumeGridHandle { /* private fields */ }Expand description
Handle for a registered volume grid.
Implementations
Sourceimpl VolumeGridHandle
impl VolumeGridHandle
Sourcepub fn set_edge_color(&self, color: Vec3) -> &Self
pub fn set_edge_color(&self, color: Vec3) -> &Self
Sets the edge color.
Sourcepub fn set_edge_width(&self, width: f32) -> &Self
pub fn set_edge_width(&self, width: f32) -> &Self
Sets the edge width.
Sourcepub fn add_node_scalar_quantity(&self, name: &str, values: Vec<f32>) -> &Self
pub fn add_node_scalar_quantity(&self, name: &str, values: Vec<f32>) -> &Self
Adds a node scalar quantity.
Sourcepub fn add_cell_scalar_quantity(&self, name: &str, values: Vec<f32>) -> &Self
pub fn add_cell_scalar_quantity(&self, name: &str, values: Vec<f32>) -> &Self
Adds a cell scalar quantity.
Sourcepub fn set_cube_size_factor(&self, factor: f32) -> &Self
pub fn set_cube_size_factor(&self, factor: f32) -> &Self
Sets the cube size factor (0 = no cubes, 1 = full size).
Sourcepub fn set_quantity_enabled(&self, quantity_name: &str, enabled: bool) -> &Self
pub fn set_quantity_enabled(&self, quantity_name: &str, enabled: bool) -> &Self
Enables a quantity by name.
Sourcepub fn set_node_scalar_viz_mode(
&self,
quantity_name: &str,
mode: VolumeGridVizMode,
) -> &Self
pub fn set_node_scalar_viz_mode( &self, quantity_name: &str, mode: VolumeGridVizMode, ) -> &Self
Sets the visualization mode for a node scalar quantity.
Sourcepub fn set_isosurface_level(&self, quantity_name: &str, level: f32) -> &Self
pub fn set_isosurface_level(&self, quantity_name: &str, level: f32) -> &Self
Sets the isosurface level for a node scalar quantity.
Sourcepub fn set_isosurface_color(&self, quantity_name: &str, color: Vec3) -> &Self
pub fn set_isosurface_color(&self, quantity_name: &str, color: Vec3) -> &Self
Sets the isosurface color for a node scalar quantity.
Sourcepub fn set_color_map(&self, quantity_name: &str, color_map: &str) -> &Self
pub fn set_color_map(&self, quantity_name: &str, color_map: &str) -> &Self
Sets the color map for a quantity (node or cell scalar).