pub fn with_camera_view_ref<F, R>(name: &str, f: F) -> Option<R>where
F: FnOnce(&CameraView) -> R,Expand description
Executes a closure with immutable access to a registered camera view.
Returns None if the camera view does not exist.
pub fn with_camera_view_ref<F, R>(name: &str, f: F) -> Option<R>where
F: FnOnce(&CameraView) -> R,Executes a closure with immutable access to a registered camera view.
Returns None if the camera view does not exist.