pub fn with_curve_network<F, R>(name: &str, f: F) -> Option<R>where
F: FnOnce(&mut CurveNetwork) -> R,Expand description
Executes a closure with mutable access to a registered curve network.
Returns None if the curve network does not exist.
pub fn with_curve_network<F, R>(name: &str, f: F) -> Option<R>where
F: FnOnce(&mut CurveNetwork) -> R,Executes a closure with mutable access to a registered curve network.
Returns None if the curve network does not exist.