pub fn with_point_cloud_ref<F, R>(name: &str, f: F) -> Option<R>where
F: FnOnce(&PointCloud) -> R,Expand description
Executes a closure with immutable access to a registered point cloud.
Returns None if the point cloud does not exist.
pub fn with_point_cloud_ref<F, R>(name: &str, f: F) -> Option<R>where
F: FnOnce(&PointCloud) -> R,Executes a closure with immutable access to a registered point cloud.
Returns None if the point cloud does not exist.